@@ -28,9 +28,9 @@
 *        Initial version. Define all SLA prototypes in PAL form even
 *        though none are implemented.
 *     16-FEB-2012 (DSB):
-*        If the PAL and SOFA libraries distributed within AST are being
+*        If the PAL and ERFA libraries distributed within AST are being
 *        used, rename the public symbols defined by both to avoid clashes
-*        with any external PAL or SOFA library.
+*        with any external PAL or ERFA library.
 *     {enter_further_changes_here}
 
 *  Copyright:
@@ -65,20 +65,28 @@
 #include <config.h>
 #endif
 
-/* If we not using external PAL and SOFA libraries, rename all PAL
+/* If we not using external PAL and ERFA libraries, rename all PAL
    functions so that references to "palXxx" below get translated to
    "astPalXxx". */
 #ifndef EXTERNAL_PAL
 #include "pal2ast.h"
 #endif
 
+/* Prototypes for all PAL functions. Note, these should be copied
+   verbatim from the pal.h file included in the pal library. We cannot
+   simply "include pal./pal.h" here as the macros established in
+   pal2ast.h above would then not be used to replace the names of the pal
+   function. */
+
+/* ------------- start of pal/pal.h ------------------------------ */
+
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
 #include <math.h>
-
-/* Prototypes for all PAL functions. */
+#include <stdlib.h>
 
 void palAddet ( double rm, double dm, double eq, double *rc, double *dc );
 
@@ -267,7 +275,7 @@ void palEg50 ( double dr, double dd, double *dl, double *db );
 
 void palEl2ue ( double date, int jform, double epoch, double orbinc,
                 double anode, double perih, double aorq, double e,
-                double aorl, double dm, double u[], int *jstat );
+                double aorl, double dm, double u[13], int *jstat );
 
 double palEpb ( double date );
 
@@ -279,6 +287,9 @@ double palEpj ( double date );
 
 double palEpj2d ( double epj );
 
+void palEpv( double date, double ph[3], double vh[3],
+             double pb[3], double vb[3] );
+
 void palEqecl ( double dr, double dd, double date, double *dl, double *db );
 
 double palEqeqx ( double date );
@@ -388,7 +399,10 @@ void palOap ( const char *type, double ob1, double ob2, double date,
 void palOapqk ( const char *type, double ob1, double ob2, double aoprms[14],
                 double *rap, double *dap );
 
-void palObs ( int n, char *c, char *name, double *w, double *p, double *h );
+int palObs( size_t n, const char * c,
+            char * ident, size_t identlen,
+            char * name, size_t namelen,
+            double * w, double * p, double * h );
 
 double palPa ( double ha, double dec, double phi );
 
@@ -411,7 +425,7 @@ void palPertel (int jform, double date0, double date1,
                 double *perih1, double *aorq1, double *e1, double *am1,
                 int *jstat );
 
-void palPertue ( double date, double u[], int *jstat );
+void palPertue ( double date, double u[13], int *jstat );
 
 void palPlanel ( double date, int jform, double epoch, double orbinc,
                  double anode, double perih, double aorq,  double e,
@@ -424,7 +438,7 @@ void palPlante ( double date, double elong, double phi, int jform,
                  double aorq, double e, double aorl, double dm,
                  double *ra, double *dec, double *r, int *jstat );
 
-void palPlantu ( double date, double elong, double phi, double u[],
+void palPlantu ( double date, double elong, double phi, const double u[13],
                  double *ra, double *dec, double *r, int *jstat );
 
 void palPm ( double r0, double d0, double pr, double pd,
@@ -445,13 +459,13 @@ void palPreces ( const char sys[3], double ep0, double ep1,
 
 void palPrenut ( double epoch, double date, double rmatpn[3][3] );
 
-void palPv2el ( double pv[], double date, double pmass, int jformr,
+void palPv2el ( const double pv[6], double date, double pmass, int jformr,
                 int *jform, double *epoch, double *orbinc,
                 double *anode, double *perih, double *aorq, double *e,
                 double *aorl, double *dm, int *jstat );
 
-void palPv2ue ( double pv[], double date, double pmass,
-                double u[], int *jstat );
+void palPv2ue ( const double pv[6], double date, double pmass,
+                double u[13], int *jstat );
 
 void palPvobs ( double p, double h, double stl, double pv[6] );
 
@@ -483,7 +497,7 @@ void palRefv ( double vu[3], double refa, double refb, double vr[3] );
 
 void palRefz ( double zu, double refa, double refb, double *zr );
 
-float palRverot ( float phi, float ra, float da, float st );
+double palRverot ( double phi, double ra, double da, double st );
 
 double palRvgalc ( double r2000, double d2000 );
 
@@ -530,12 +544,12 @@ void palTps2c ( float xi, float eta, float ra, float dec,
 void palTpv2c ( float xi, float eta, float v[3],
                 float v01[3], float v02[3], int *n );
 
-void palUe2el ( double u[], int jformr,
+void palUe2el ( const double u[13], int jformr,
                 int *jform, double *epoch, double *orbinc,
                 double *anode, double *perih, double *aorq, double *e,
                 double *aorl, double *dm, int *jstat );
 
-void palUe2pv ( double date, double u[], double pv[], int *jstat );
+void palUe2pv ( double date, double u[13], double pv[], int *jstat );
 
 void palUnpcd ( double disco, double *x, double *y );
 
@@ -556,4 +570,9 @@ double palZd ( double ha, double dec, double phi );
 }
 #endif
 
+/* ------------- end of pal/pal.h ------------------------------ */
+
+
+
+
 #endif
